import React, { useState, useEffect } from 'react';
import { b as useDevcontainers } from './index-957552d7.esm.js';
import { InfoCard } from '@backstage/core-components';
import { makeStyles } from '@material-ui/core';
import '@backstage/core-plugin-api';
import '@backstage/plugin-catalog-react';

const visuallyHiddenStyles = {
  display: "inline-block",
  position: "absolute",
  overflow: "hidden",
  clip: "rect(0 0 0 0)",
  height: 1,
  width: 1,
  margin: -1,
  padding: 0,
  border: 0
};
const VisuallyHidden = ({
  children,
  ...delegatedProps
}) => {
  const [forceShow, setForceShow] = useState(false);
  useEffect(() => {
    if (process.env.NODE_ENV === "production") {
      return void 0;
    }
    const handleKeyDown = (event) => {
      if (event.shiftKey && event.key === "Alt") {
        setForceShow(true);
      }
    };
    const handleKeyUp = (event) => {
      if (event.key === "Alt") {
        setForceShow(false);
      }
    };
    window.addEventListener("keydown", handleKeyDown);
    window.addEventListener("keyup", handleKeyUp);
    return () => {
      window.removeEventListener("keydown", handleKeyDown);
      window.removeEventListener("keyup", handleKeyUp);
    };
  }, []);
  if (forceShow) {
    return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
  }
  return /* @__PURE__ */ React.createElement("span", { style: visuallyHiddenStyles, ...delegatedProps }, children);
};

const useStyles = makeStyles(() => ({
  link: {
    textDecoration: "underline",
    "&:hover": {
      textDecoration: "none"
    }
  },
  tagName: {
    fontWeight: 700
  }
}));
const ExampleDevcontainersComponent = () => {
  const state = useDevcontainers();
  const styles = useStyles();
  return /* @__PURE__ */ React.createElement(InfoCard, { title: "Devcontainers plugin" }, /* @__PURE__ */ React.createElement("p", null, "Searched component entity for VS Code URL and tag:", " ", /* @__PURE__ */ React.createElement("span", { className: styles.tagName }, state.tagName)), state.hasUrl ? /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement("p", null, "Your entity supports Dev Containers!"), /* @__PURE__ */ React.createElement("a", { href: state.vsCodeUrl, className: styles.link }, "Click here to launch VSCode", /* @__PURE__ */ React.createElement(VisuallyHidden, null, " (link opens in new tab)"))) : /* @__PURE__ */ React.createElement("p", null, "No Dev Containers plugin tag detected"));
};

export { ExampleDevcontainersComponent };
//# sourceMappingURL=index-8c2c53e7.esm.js.map
