import { createRouteRef, createPlugin, createComponentExtension } from '@backstage/core-plugin-api';
import React, { createContext, useContext, useMemo } from 'react';
import { useEntity } from '@backstage/plugin-catalog-react';

const rootRouteRef = createRouteRef({
  id: "backstage-plugin-devcontainers-react"
});

const DEFAULT_DEVCONTAINERS_TAG = "devcontainers-plugin";
const ConfigContext = createContext(null);
function useDevcontainersConfig() {
  const contextValue = useContext(ConfigContext);
  if (contextValue === null) {
    throw new Error(
      `${useDevcontainersConfig.name} is being called outside of a Devcontainers context`
    );
  }
  return contextValue;
}
const DevcontainersProvider$1 = ({ children, config }) => {
  const stableConfig = useMemo(() => {
    var _a;
    return {
      tagName: (_a = config.tagName) != null ? _a : DEFAULT_DEVCONTAINERS_TAG
    };
  }, [config]);
  return /* @__PURE__ */ React.createElement(ConfigContext.Provider, { value: stableConfig }, children);
};

const vsCodeUrlKey = "vsCodeUrl";
function useDevcontainers() {
  var _a, _b, _c;
  const { tagName } = useDevcontainersConfig();
  const { entity } = useEntity();
  const tags = (_b = (_a = entity.metadata) == null ? void 0 : _a.tags) != null ? _b : [];
  if (!tags.includes(tagName)) {
    return {
      tagName,
      hasUrl: false,
      vsCodeUrl: void 0
    };
  }
  const vsCodeUrl = (_c = entity.metadata.annotations) == null ? void 0 : _c[vsCodeUrlKey];
  if (!vsCodeUrl) {
    return {
      tagName,
      hasUrl: false,
      vsCodeUrl: void 0
    };
  }
  return {
    tagName,
    hasUrl: true,
    vsCodeUrl
  };
}

const devcontainersPlugin = createPlugin({
  id: "backstage-plugin-devcontainers-react",
  routes: {
    root: rootRouteRef
  }
});
const DevcontainersProvider = devcontainersPlugin.provide(
  createComponentExtension({
    name: "DevcontainersProvider",
    component: {
      lazy: () => import('./index-6f8d9071.esm.js').then(
        (m) => m.DevcontainersProvider
      )
    }
  })
);
const ExampleDevcontainersComponent = devcontainersPlugin.provide(
  createComponentExtension({
    name: "ExampleDevcontainersComponent",
    component: {
      lazy: () => import('./index-8c2c53e7.esm.js').then(
        (m) => m.ExampleDevcontainersComponent
      )
    }
  })
);

export { DEFAULT_DEVCONTAINERS_TAG as D, ExampleDevcontainersComponent as E, DevcontainersProvider$1 as a, useDevcontainers as b, DevcontainersProvider as c, devcontainersPlugin as d, useDevcontainersConfig as u };
//# sourceMappingURL=index-957552d7.esm.js.map
